// This file configured doctest to run, please leave empty
// Write more tests as separate files and add in CMakeLists.txt
#define DOCTEST_CONFIG_IMPLEMENT_WITH_MAIN
#include "doctest/doctest.h"
#include <nanobench.h>